from django.conf import settings

from .utils import get_base

DEFAULT_THEME = "simple"


def django_style(request):
    theme = getattr(settings, "STYLE_THEME", DEFAULT_THEME)
    return {
        "STYLE_BASE": get_base(theme),
        "STYLE_IS_APP": getattr(settings, "STYLE_IS_APP", False),
    }



from django.apps import AppConfig
from django.conf import settings


class StyleConfig(AppConfig):
    name = "django_style"

    def ready(self):
        # Inject the django_style template context processor
        if hasattr(settings, "TEMPLATES"):
            for template in settings.TEMPLATES:
                if (
                    "OPTIONS" in template
                    and "context_processors" in template["OPTIONS"]
                ):
                    template["OPTIONS"]["context_processors"].append(
                        "django_style.context_processors.django_style"
                    )



from nanodjango import hookimpl


@hookimpl
def django_pre_setup(app):
    from django.conf import settings

    app_name = "django_style"
    if app_name not in settings.INSTALLED_APPS:
        settings.INSTALLED_APPS.append(app_name)


from django.urls import reverse_lazy

from .constants import THEMES


class Nav:
    """
    Describe a navigation item
    """

    def __init__(self, label: str, view: str):
        self.label = label
        self.view = view
        self.url = reverse_lazy(view)


def get_base(theme: str) -> str:
    """
    Given a theme name, generate the STYLE_BASE value

    May be useful if wanting to override the STYLE_BASE in a context, eg:

        render(..., context={"STYLE_BASE": get_base("simple")})
    """
    if theme not in THEMES:
        raise ValueError(f"Unknown django-style theme: {theme}")
    return f"django_style/{theme}/base.html"
